Index: /issm/trunk-jpl/src/c/classes/objects/Elements/Element.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/objects/Elements/Element.h	(revision 14377)
+++ /issm/trunk-jpl/src/c/classes/objects/Elements/Element.h	(revision 14378)
@@ -73,9 +73,9 @@
 		virtual IssmDouble TimeAdapt()=0;
 		virtual void   MigrateGroundingLine(IssmDouble* old_floating_ice,IssmDouble* sheet_ungrounding)=0;
-		virtual void   PotentialSheetUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding)=0;
+		virtual void   PotentialUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding)=0;
 		virtual void   PositiveDegreeDay(IssmDouble* pdds,IssmDouble* pds,IssmDouble signorm)=0;
 		virtual void   Delta18oParameterization(void)=0;
 		virtual void   SmbGradients()=0;
-		virtual int    UpdatePotentialSheetUngrounding(IssmDouble* potential_sheet_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf)=0;
+		virtual int    UpdatePotentialUngrounding(IssmDouble* potential_sheet_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf)=0;
 		virtual void   ResetCoordinateSystem()=0;
 		virtual void   SmearFunction(Vector<IssmDouble>* smearedvector,IssmDouble (*WeightFunction)(IssmDouble distance,IssmDouble radius),IssmDouble radius)=0;
Index: /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.h	(revision 14377)
+++ /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.h	(revision 14378)
@@ -105,5 +105,5 @@
 		void   InputToResult(int enum_type,int step,IssmDouble time);
 		void   MigrateGroundingLine(IssmDouble* old_floating_ice,IssmDouble* sheet_ungrounding);
-		void   PotentialSheetUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding);
+		void   PotentialUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding);
 		void   RequestedOutput(int output_enum,int step,IssmDouble time);
 		void   ListResultsInfo(int** results_enums,int** results_size,IssmDouble** results_times,int** results_steps,int* num_results);
@@ -116,5 +116,5 @@
 		IssmDouble SurfaceArea(void);
 		void   Update(int index, IoModel* iomodel,int analysis_counter,int analysis_type);
-		int    UpdatePotentialSheetUngrounding(IssmDouble* potential_sheet_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf);
+		int    UpdatePotentialUngrounding(IssmDouble* potential_sheet_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf);
 		int    NodalValue(IssmDouble* pvalue, int index, int natureofdataenum,bool process_units);
 		IssmDouble TimeAdapt();
Index: /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.h
===================================================================
--- /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.h	(revision 14377)
+++ /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.h	(revision 14378)
@@ -105,5 +105,5 @@
 		void   MigrateGroundingLine(IssmDouble* oldfloating,IssmDouble* sheet_ungrounding);
 		int    NodalValue(IssmDouble* pvalue, int index, int natureofdataenum,bool process_units);
-		void   PotentialSheetUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding);
+		void   PotentialUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding);
 		void   PositiveDegreeDay(IssmDouble* pdds,IssmDouble* pds,IssmDouble signorm);
 		void   RequestedOutput(int output_enum,int step,IssmDouble time);
@@ -116,5 +116,5 @@
 		IssmDouble SurfaceArea(void);
 		void   Update(int index, IoModel* iomodel,int analysis_counter,int analysis_type);
-		int    UpdatePotentialSheetUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf);
+		int    UpdatePotentialUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf);
 		IssmDouble TimeAdapt();
 		int*   GetHorizontalNeighboorSids(void);
Index: /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.cpp
===================================================================
--- /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.cpp	(revision 14377)
+++ /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.cpp	(revision 14378)
@@ -31,5 +31,5 @@
 	if(migration_style==SoftMigrationEnum){
 		/*Create flag for grounded vertices above the hydrostatic equilibrium: */
-		vertices_potentially_ungrounding=PotentialSheetUngrounding(elements,vertices,parameters);
+		vertices_potentially_ungrounding=PotentialUngrounding(elements,vertices,parameters);
 
 		/*propagate ice shelf into connex areas of the ice sheet that potentially want to unground: */
@@ -81,6 +81,6 @@
 }
 /*%}}}*/
-/*FUNCTION PotentialSheetUngrounding {{{*/
-IssmDouble*    PotentialSheetUngrounding(Elements* elements,Vertices* vertices,Parameters* parameters){ 
+/*FUNCTION PotentialUngrounding {{{*/
+IssmDouble*    PotentialUngrounding(Elements* elements,Vertices* vertices,Parameters* parameters){ 
 
 	int      i,numberofvertices;
@@ -96,5 +96,5 @@
 	for(i=0;i<elements->Size();i++){
 		element=dynamic_cast<Element*>(elements->GetObjectByOffset(i));
-		element->PotentialSheetUngrounding(vec_vertices_potentially_ungrounding);
+		element->PotentialUngrounding(vec_vertices_potentially_ungrounding);
 	}
 
@@ -150,5 +150,5 @@
 			element=dynamic_cast<Element*>(elements->GetObjectByOffset(i));
 			if(reCast<int,IssmDouble>(elements_neighboring_floatingce[element->Sid()])){
-				local_nflipped+=element->UpdatePotentialSheetUngrounding(vertices_potentially_ungrounding,vec_nodes_on_floatingice,nodes_on_floatingice);
+				local_nflipped+=element->UpdatePotentialUngrounding(vertices_potentially_ungrounding,vec_nodes_on_floatingice,nodes_on_floatingice);
 			}
 		}
Index: /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.h
===================================================================
--- /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.h	(revision 14377)
+++ /issm/trunk-jpl/src/c/modules/GroundinglineMigrationx/GroundinglineMigrationx.h	(revision 14378)
@@ -14,6 +14,6 @@
 void       GroundinglineMigrationx(Elements* elements,Nodes* nodes, Vertices* vertices,Loads* loads,Materials* materials, Parameters* parameters);
 
-Vector<IssmDouble>*        CreateNodesOnFloatingIce(Nodes* nodes,int configuration_type);
-IssmDouble*    PotentialSheetUngrounding(Elements* elements,Vertices* vertices,Parameters* parameters);
+Vector<IssmDouble>* CreateNodesOnFloatingIce(Nodes* nodes,int configuration_type);
+IssmDouble*    PotentialUngrounding(Elements* elements,Vertices* vertices,Parameters* parameters);
 IssmDouble*    PropagateFloatingiceToGroundedNeighbors(Elements* elements,Nodes* nodes,Vertices* vertices,Parameters* parameters,IssmDouble* vertices_potentially_ungrounding);
 #endif  /* _GROUNDINGLINEMIGRATIONX_H */

Index: /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.cpp	(revision 14377)
+++ /issm/trunk-jpl/src/c/classes/objects/Elements/Penta.cpp	(revision 14378)
@@ -2159,5 +2159,5 @@
 
 	int     i,migration_style,unground;
-	bool    elementonshelf = false;
+	bool    floatingelement = false;
 	IssmDouble  bed_hydro,yts,gl_melting_rate;
 	IssmDouble  rho_water,rho_ice,density;
@@ -2215,5 +2215,5 @@
 	for(i=0;i<NUMVERTICES;i++){
 		if(nodes[i]->IsFloating()){
-			elementonshelf=true;
+			floatingelement=true;
 			break;
 		}
@@ -2221,5 +2221,5 @@
 
    /*Add basal melting rate if element just ungrounded*/
-	if(!this->IsFloating() && elementonshelf==true){
+	if(!this->IsFloating() && floatingelement==true){
 		for(i=0;i<NUMVERTICES;i++)melting[i]=gl_melting_rate/yts;
 		this->inputs->AddInput(new PentaP1Input(BasalforcingsMeltingRateEnum,&melting[0]));
@@ -2229,5 +2229,5 @@
 	this->inputs->AddInput(new PentaP1Input(SurfaceEnum,&s[0]));
 	this->inputs->AddInput(new PentaP1Input(BedEnum,&b[0]));
-   this->inputs->AddInput(new BoolInput(MaskElementonfloatingiceEnum,elementonshelf));
+   this->inputs->AddInput(new BoolInput(MaskElementonfloatingiceEnum,floatingelement));
 
 	/*Extrude inputs*/
@@ -2391,6 +2391,6 @@
 }
 /*}}}*/
-/*FUNCTION Penta::PotentialSheetUngrounding{{{*/
-void  Penta::PotentialSheetUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding){
+/*FUNCTION Penta::PotentialUngrounding{{{*/
+void  Penta::PotentialUngrounding(Vector<IssmDouble>* potential_ungrounding){
 
 	int     i;
@@ -2398,5 +2398,4 @@
 	IssmDouble  bed_hydro;
 	IssmDouble  rho_water,rho_ice,density;
-	bool    elementonshelf = false;
 
 	/*material parameters: */
@@ -2414,5 +2413,5 @@
 			if (bed_hydro>ba[i]){
 				/*Vertex that could potentially unground, flag it*/
-				potential_sheet_ungrounding->SetValue(nodes[i]->Sid(),1,INS_VAL);
+				potential_ungrounding->SetValue(nodes[i]->Sid(),1,INS_VAL);
 			}
 		}
@@ -3013,11 +3012,11 @@
 }
 /*}}}*/
-/*FUNCTION Penta::UpdatePotentialSheetUngrounding{{{*/
-int Penta::UpdatePotentialSheetUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf){
+/*FUNCTION Penta::UpdatePotentialUngrounding{{{*/
+int Penta::UpdatePotentialUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf){
 
 	int i;
 	int nflipped=0;
 
 	/*Go through nodes, and whoever is on the potential_sheet_ungrounding, ends up in nodes_on_iceshelf: */
 	for(i=0;i<NUMVERTICES;i++){
 		if (reCast<bool,IssmDouble>(vertices_potentially_ungrounding[nodes[i]->Sid()])){
@@ -3013,11 +3012,11 @@
 	int nflipped=0;
 
-	/*Go through nodes, and whoever is on the potential_sheet_ungrounding, ends up in nodes_on_iceshelf: */
+	/*Go through nodes, and whoever is on the potential_ungrounding, ends up in nodes_on_iceshelf: */
 	for(i=0;i<NUMVERTICES;i++){
 		if (reCast<bool,IssmDouble>(vertices_potentially_ungrounding[nodes[i]->Sid()])){
Index: /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.cpp	(revision 14377)
+++ /issm/trunk-jpl/src/c/classes/objects/Elements/Tria.cpp	(revision 14378)
@@ -2139,6 +2139,6 @@
 
 	int     i,migration_style;
-	bool    elementonshelf = false;
-	bool    elementonsheet = false;
+	bool    floatingelement = false;
+	bool    groundedelement = false;
 	IssmDouble  bed_hydro,yts,gl_melting_rate;
 	IssmDouble  rho_water,rho_ice,density;
@@ -2199,9 +2199,9 @@
 		for(i=0;i<NUMVERTICES;i++){
 			if(nodes[i]->IsGrounded()){
-				elementonsheet=true;
+				groundedelement=true;
 				break;
 			}
 		}
-		elementonshelf=!elementonsheet;
+		floatingelement=!groundedelement;
 	}
 	else{
@@ -2209,5 +2209,5 @@
 		for(i=0;i<NUMVERTICES;i++){
 			if(nodes[i]->IsFloating()){
-				elementonshelf=true;
+				floatingelement=true;
 				break;
 			}
@@ -2216,5 +2216,5 @@
 
    /*Add basal melting rate if element just ungrounded*/
-	if(!this->IsFloating() && elementonshelf==true){
+	if(!this->IsFloating() && floatingelement==true){
 		for(i=0;i<NUMVERTICES;i++)melting[i]=gl_melting_rate/yts;
 		this->inputs->AddInput(new TriaP1Input(BasalforcingsMeltingRateEnum,&melting[0]));
@@ -2222,5 +2222,5 @@
 
 	/*Update inputs*/
-   this->inputs->AddInput(new BoolInput(MaskElementonfloatingiceEnum,elementonshelf));
+   this->inputs->AddInput(new BoolInput(MaskElementonfloatingiceEnum,floatingelement));
 	this->inputs->AddInput(new TriaP1Input(SurfaceEnum,&s[0]));
 	this->inputs->AddInput(new TriaP1Input(BedEnum,&b[0]));
@@ -2317,6 +2317,6 @@
 }
 /*}}}*/
-/*FUNCTION Tria::PotentialSheetUngrounding{{{*/
-void  Tria::PotentialSheetUngrounding(Vector<IssmDouble>* potential_sheet_ungrounding){
+/*FUNCTION Tria::PotentialUngrounding{{{*/
+void  Tria::PotentialUngrounding(Vector<IssmDouble>* potential_ungrounding){
 
 	int     i;
@@ -2324,5 +2324,4 @@
 	IssmDouble  bed_hydro;
 	IssmDouble  rho_water,rho_ice,density;
-	bool    elementonshelf = false;
 
 	/*material parameters: */
@@ -2333,5 +2332,5 @@
 	GetInputListOnVertices(&ba[0],BathymetryEnum);
 
-	/*go through vertices, and figure out which ones are on the ice sheet, and want to unground: */
+	/*go through vertices, and figure out which ones are grounded and want to unground: */
 	for(i=0;i<NUMVERTICES;i++){
 		/*Find if grounded vertices want to start floating*/
@@ -2340,5 +2339,5 @@
 			if (bed_hydro>ba[i]){
 				/*Vertex that could potentially unground, flag it*/
-				potential_sheet_ungrounding->SetValue(nodes[i]->Sid(),1,INS_VAL);
+				potential_ungrounding->SetValue(nodes[i]->Sid(),1,INS_VAL);
 			}
 		}
@@ -2702,11 +2701,11 @@
 }
 /*}}}*/
-/*FUNCTION Tria::UpdatePotentialSheetUngrounding{{{*/
-int Tria::UpdatePotentialSheetUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf){
+/*FUNCTION Tria::UpdatePotentialUngrounding{{{*/
+int Tria::UpdatePotentialUngrounding(IssmDouble* vertices_potentially_ungrounding,Vector<IssmDouble>* vec_nodes_on_iceshelf,IssmDouble* nodes_on_iceshelf){
 
 	int i;
 	int nflipped=0;
 
 	/*Go through nodes, and whoever is on the potential_sheet_ungrounding, ends up in nodes_on_iceshelf: */
 	for(i=0;i<3;i++){
 		if (reCast<bool>(vertices_potentially_ungrounding[nodes[i]->Sid()])){
@@ -2702,11 +2701,11 @@
 	int nflipped=0;
 
-	/*Go through nodes, and whoever is on the potential_sheet_ungrounding, ends up in nodes_on_iceshelf: */
+	/*Go through nodes, and whoever is on the potential_ungrounding, ends up in nodes_on_iceshelf: */
 	for(i=0;i<3;i++){
 		if (reCast<bool>(vertices_potentially_ungrounding[nodes[i]->Sid()])){